==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/procedures/GetAudiosProcess.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- [dbo].[GetAudiosProcess] 5, 1, 'allegro', 'proceso1', '', '2019-04-11 00:00:00.000', '2019-06-06 04:59:59.997', 22, 26, 23, 59, 'entrantes,PruebasJair,VideoCall', 'icagente', NULL, 'allegro', '', ''
CREATE PROCEDURE [dbo].[GetAudiosProcess]
(
	@PageSize				INT,
	@PageNumber				INT,
	@VCC					VARCHAR(50),
	@ProcessId				VARCHAR(50),
	@ID						VARCHAR(250),
	@StartDate				DATETIME = NULL,
	@EndDate				DATETIME = NULL,
	@StartHour				INT,
	@StartMinute			INT,
	@EndHour				INT,
	@EndMinute				INT,
	@Campaign				VARCHAR(MAX),
	@Agent					VARCHAR(MAX),
	@ResultCode				VARCHAR(MAX),
	@Type					VARCHAR(50),
	@IdathaResults			NVARCHAR(MAX),
	@TotalIdathaResults		INT,
	@InteractionType		VARCHAR(50),
	@Folder					VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON
	
	-- DEFINIMOS UNA TABLE TEMPORAL PARA DEPOSITAR LA TODOS LAS INTERACCIONES DEL PROCESS
	CREATE TABLE #PROCESS_INTERACTIONS(
		vcc VARCHAR(50),
		interactionType VARCHAR(100),
		id VARCHAR(250),
		section VARCHAR(100),
		part VARCHAR(100),
		processId VARCHAR(100),
		number VARCHAR(100),
		name VARCHAR(100),
		silenceTime INT,
		durationTime INT,
		durationLinguisticTime INT,
		category1 VARCHAR(100),
		category2 VARCHAR(100),
		category3 VARCHAR(100),
		agent VARCHAR(100),
		description VARCHAR(100),
		environment VARCHAR(100),
		isTranscribed VARCHAR(100),
		errorMessage VARCHAR(100),
		createdDate DATETIME,
		endDate DATETIME,
		campaign VARCHAR(50),
		dispositionCode VARCHAR(250),
		folder VARCHAR(50)
	)

	-- INSERTAMOS LOS REGISTROS CALL
	INSERT INTO #PROCESS_INTERACTIONS
		SELECT A.[VCC]						'vcc',
				'CALL'						'interactionType',
				A.[ID]						'id',
				A.[Section]					'section',
				A.[Part]					'part',
				PA.[ProcessId]				'processId',
				A.[Number]					'number',
				P.[Name]					'name',
				A.[SilenceTime]				'silenceTime',
				A.[DurationTime]			'durationTime',
				A.[DurationLinguisticTime]	'durationLinguisticTime',
				A.[Category1]				'category1',
				A.[Category2]				'category2',
				A.[Category3]				'category3',
				A.[Agent]					'agent',
				A.[Description]				'description',
				P.[Environment]				'environment',
				A.[IsTranscribed]			'isTranscribed',
				A.[ErrorMessage]			'errorMessage',
				A.[CreatedDate]				'createdDate',
				A.[EndDate]					'endDate',
				A.[Campaign]				'campaign',
				A.[DispositionCode]			'dispositionCode',
				NULL						'folder'
			FROM [dbo].[Audio] A (NOLOCK)
			INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
				ON A.ID = PA.AudioId 
					AND A.Section = PA.Section 
					AND A.Part = PA.Part
			INNER JOIN [dbo].[Process] P (NOLOCK) 
				ON PA.[ProcessId] = P.[Name]
			WHERE A.[VCC] = @VCC
				AND PA.[ProcessId] = @ProcessId
				AND P.[Type] = 'SPEECH'
				
	-- INSERTAMOS LOS REGISTROS DE INTERACCIONES DE OTROS CANALES
	INSERT INTO #PROCESS_INTERACTIONS
		SELECT AI.[VCC]						'vcc',
				AI.[Channel]				'interactionType',
				AI.[ID]						'id',
				NULL						'section',
				NULL						'part',
				PAI.[ProcessId]				'processId',
				AI.[ContactName]			'number',
				PAI.[ProcessId]				'name',
				NULL						'silenceTime',
				CASE WHEN TRY_CAST(AI.[DurationTime] AS INT) IS NULL THEN
					CAST(SUBSTRING(AI.[DurationTime], 1, CHARINDEX(':', AI.[DurationTime], 1) - 1) AS INT) * 3600
					+
					CAST(SUBSTRING(AI.[DurationTime], CHARINDEX(':', AI.[DurationTime], 1) + 1, 2) AS INT) * 60
					+
					CAST(SUBSTRING(AI.[DurationTime], CHARINDEX(':', AI.[DurationTime], CHARINDEX(':', AI.[DurationTime], 1) + 1) + 1, 2) AS INT)
				ELSE AI.[DurationTime]
				END							'durationTime',
				NULL						'durationLinguisticTime',
				NULL						'category1',
				NULL						'category2',
				NULL						'category3',
				AI.[FirstTakedAgent]		'agent',
				AI.[DispositionCode]		'description',
				'I6'						'environment',
				AI.[IsTranscribed]			'isTranscribed',
				AI.[ErrorMessage]			'errorMessage',
				AI.[CreatedDate]			'createdDate',
				AI.[EndDate]				'endDate',
				AI.[Campaign]				'campaign',
				AI.[DispositionTreePath]	'dispositionCode',
				AI.[Folder]					'folder'
			FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
			INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON AI.[VCC] = PAI.[VCC]
					--AND AI.[Campaign] = PAI.[Campaign]
					AND AI.[Channel] = PAI.[InteractionType]
					AND AI.[ID] = PAI.[InteractionId]
					AND AI.[Folder] = PAI.[FormattedEndDate]
			INNER JOIN [dbo].[Process] P (NOLOCK) 
				ON P.[Name] = PAI.[ProcessId]
			WHERE PAI.[VCC] = @VCC
				AND PAI.[ProcessId] = @ProcessId
				AND P.[Type] = 'SPEECH'
		
	-- DECLARAMOS VARIABLE PARA LA CONSULTA ACUMULADA QUE LANZAREMOS
	DECLARE @SQL NVARCHAR(MAX) = ''
	DECLARE @SQL_WHERE NVARCHAR(MAX) = ''
	DECLARE @SQL_WHERE_IDATHA NVARCHAR(MAX) = ''
	
	SET @SQL_WHERE = ''
	SET @SQL_WHERE_IDATHA = ''

	-- HACEMOS EL PRIMER QUERY PARA SACAR EL NUMERO DE REGISTROS DEL PROCESS
	SET @SQL = ' SET NOCOUNT ON
	DECLARE @rows INT
	DECLARE @SYNC_INTERACTIONS INT
	DECLARE @ASYNC_INTERACTIONS INT
	DECLARE @maxDurationTime Numeric(12,3)

	SELECT @SYNC_INTERACTIONS = COUNT(*) FROM #PROCESS_INTERACTIONS PI WHERE PI.[interactionType] = ''CALL''
	SELECT @ASYNC_INTERACTIONS = COUNT(*) FROM #PROCESS_INTERACTIONS PI WHERE PI.[interactionType] <> ''CALL''
	SELECT @maxDurationTime = MAX([durationTime]) FROM #PROCESS_INTERACTIONS 
	'

	SET @SQL += '
		SET @rows = (
			SELECT COUNT(PI.[id])
				FROM #PROCESS_INTERACTIONS PI (NOLOCK)
				WHERE PI.[vcc] = ''' + @VCC + ''' 
					'
	IF (@ProcessId IS NOT NULL) 
			SET @SQL += 'AND PI.[ProcessId]= ''' + @ProcessId + ''' 
						'

	IF(@Type = 'query')
	BEGIN
		SET @SQL_WHERE_IDATHA += 'AND ((CONCAT(PI.[id], ''_'', PI.[section], ''_'', PI.[part]) IN (''' + @IdathaResults + '''))
						OR (PI.[id] IN (''' + @IdathaResults + ''')))
					'
	
		SET @SQL += @SQL_WHERE_IDATHA

	END
	ELSE IF(@Type = 'allegro' OR @Type = 'ftp' OR @Type = 'sftp' OR @Type = 'fileSystem')
	BEGIN
		IF (@ID IS NOT NULL) 
			SET @SQL_WHERE += 'AND ((CONCAT(PI.[id], ''_'', PI.[section], ''_'', PI.[part]) LIKE ''%' + @ID + '%'')
						OR (PI.[id] = ''' + @ID + '''))
					'
		
		IF (@Campaign IS NOT NULL AND LEN(@Campaign) > 0) 
			SET @SQL_WHERE += 'AND PI.[campaign] IN (''' + @Campaign + ''')
						'
		
		IF (@Agent IS NOT NULL AND LEN(@Agent) > 0) 
			SET @SQL_WHERE += 'AND (
									(PI.[agent] IN (''' + @Agent + '''))
									OR 
									(PI.[agent] IS NULL)
								)
						'
		
		--CORREGIR
		-- (CONCAT(PI.campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), PI.[dispositionCode]), '''') IN (''' + @ResultCode + '''))
		IF (@ResultCode IS NOT NULL AND LEN(@ResultCode) > 0) 
			SET @SQL_WHERE += 'AND (
									(CONCAT(PI.campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), PI.[dispositionCode]), ''X'')) IN (''' + @ResultCode + '''))
									OR 
									--(CONCAT(PI.campaign, ''_'', ISNULL(PI.[dispositionCode], ''X'')) IN (''' + @ResultCode + '''))
									(CONCAT(PI.campaign, ISNULL(REPLACE(PI.[dispositionCode], ''/'', ''_''), ''_'')) IN (''' + @ResultCode + '''))
									) '
		
		IF (@InteractionType IS NOT NULL AND LEN(@InteractionType) > 0) 
			SET @SQL_WHERE += 'AND PI.[interactionType] = ''' + @InteractionType + ''' 
						'

		IF (@Folder IS NOT NULL AND LEN(@Folder) > 0) 
			SET @SQL_WHERE += 'AND PI.[folder] = ''' + @Folder + ''' 
						'

		IF (@Folder IS NOT NULL AND LEN(@Folder) > 0) 

		IF (@StartDate IS NOT NULL AND @EndDate IS NOT NULL) 
			SET @SQL_WHERE += 'AND PI.[endDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' 
						AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
						'
		
		IF (@StartHour IS NOT NULL AND @EndHour IS NOT NULL) 
			SET @SQL_WHERE += 'AND DATEPART(HOUR, PI.[endDate]) >= ' + CONVERT(VARCHAR, @StartHour) + ' 
						AND DATEPART(HOUR, PI.[endDate]) <= ' + CONVERT(VARCHAR, @EndHour) + '
						'
		
		IF (@StartMinute IS NOT NULL AND @EndMinute IS NOT NULL) 
			SET @SQL_WHERE += 'AND DATEPART(MINUTE, PI.[endDate]) >= ' + CONVERT(VARCHAR, @StartMinute) + ' 
						AND DATEPART(MINUTE, PI.[endDate]) <= ' + CONVERT(VARCHAR, @EndMinute) + '
						'
		
	END

	SET @SQL += @SQL_WHERE
	SET @SQL += ') '
	SET @SQL += 'SELECT @rows AS total, 
						@maxDurationTime AS maxDurationTime,
						@ASYNC_INTERACTIONS AS asyncDetails, 
						@SYNC_INTERACTIONS AS audios '

	-- SECCION DE QUERY PARA RESUMEN DE CANALES
	SET @SQL += '
		SELECT PI.[interactionType]			''interactionType'',
				COUNT(*)					''interactions'' 
			FROM #PROCESS_INTERACTIONS PI 
			WHERE PI.[vcc] = ''' + @VCC + ''' 
	'

	IF(@ProcessId IS NOT NULL) 
		SET @SQL += '
				AND PI.[processId] = ''' + @ProcessId + ''' '
		
	SET @SQL += '
		GROUP BY  PI.[interactionType] '

	-- SECCION DE QUERY PARA RESUMEN DE CAMPANAS
	SET @SQL += '
		SELECT PI.[campaign]			''campaign''
			FROM #PROCESS_INTERACTIONS PI 
			WHERE PI.[vcc] = ''' + @VCC + ''' 
	'

	IF(@ProcessId IS NOT NULL) 
		SET @SQL += '
				AND PI.[processId] = ''' + @ProcessId + ''' '
		
	SET @SQL += '
		GROUP BY  PI.[campaign] '

	-- SECCION DE QUERY PARA LISTADO DE DETALLES(AUDIOS/TEXTOS)
	SET @SQL += '
		SELECT PI.[interactionType],
				PI.[id],
				PI.[section],
				PI.[part],
				PI.[processId],
				PI.[folder],
				PI.[campaign],
				PI.[number],
				PI.[name],
				PI.[silenceTime],
				PI.[durationTime],
				PI.[durationLinguisticTime],
				PI.[category1],
				PI.[category2],
				PI.[category3],
				PI.[agent],
				PI.[description],
				PI.[environment],
				PI.[isTranscribed],
				PI.[errorMessage],
				PI.[createdDate],
				PI.[endDate]
			FROM #PROCESS_INTERACTIONS PI
			WHERE PI.[vcc] = ''' + @VCC + ''' 
				'

	IF(@ProcessId IS NOT NULL) SET @SQL += 'AND PI.[processId] = ''' + @ProcessId + ''' '
			
	SET @SQL += ' '

	SET @SQL += @SQL_WHERE
	SET @SQL += @SQL_WHERE_IDATHA
	SET @SQL += 'ORDER BY PI.[ID], 
						PI.[ProcessId], 
						PI.[Agent], 
						PI.[Description], 
						PI.[Environment], 
						PI.[DurationTime], 
						PI.[CreatedDate]
			OFFSET ' + CONVERT(VARCHAR(50), @PageSize) + ' * (' + CONVERT(VARCHAR(50), @PageNumber) + ' - 1) ROWS
			FETCH NEXT ' + CONVERT(VARCHAR(50), @PageSize) + ' ROWS ONLY
			'

	SET @SQL += ' SET NOCOUNT OFF'
	--select @SQL
	EXEC(@SQL)
	
	DROP TABLE #PROCESS_INTERACTIONS
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_0.16.1_database.tar.gz: database/mssql/procedures/GetAudiosProcess.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- [dbo].[GetAudiosProcess] 5, 1, 'allegro', 'proceso1', '', '2019-04-11 00:00:00.000', '2019-06-06 04:59:59.997', 22, 26, 23, 59, 'entrantes,PruebasJair,VideoCall', 'icagente', NULL, 'allegro', '', ''
CREATE PROCEDURE [dbo].[GetAudiosProcess]
(
	@PageSize				INT,
	@PageNumber				INT,
	@VCC					VARCHAR(50),
	@ProcessId				VARCHAR(50),
	@ID						VARCHAR(250),
	@StartDate				DATETIME = NULL,
	@EndDate				DATETIME = NULL,
	@StartHour				INT,
	@StartMinute			INT,
	@EndHour				INT,
	@EndMinute				INT,
	@Campaign				VARCHAR(MAX),
	@Agent					VARCHAR(MAX),
	@ResultCode				VARCHAR(MAX),
	@Type					VARCHAR(50),
	@IdathaResults			NVARCHAR(MAX),
	@TotalIdathaResults		INT,
	@InteractionType		VARCHAR(50),
	@InteractionIds         VARCHAR(MAX) = NULL,
	@Folder					VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON
	
	-- DEFINIMOS UNA TABLE TEMPORAL PARA DEPOSITAR LA TODOS LAS INTERACCIONES DEL PROCESS
	CREATE TABLE #PROCESS_INTERACTIONS(
		vcc VARCHAR(50),
		interactionType VARCHAR(100),
		id VARCHAR(250),
		section VARCHAR(100),
		part VARCHAR(100),
		processId VARCHAR(100),
		number VARCHAR(100),
		name VARCHAR(100),
		silenceTime INT,
		durationTime INT,
		durationLinguisticTime INT,
		category1 VARCHAR(100),
		category2 VARCHAR(100),
		category3 VARCHAR(100),
		agent VARCHAR(100),
		agentName VARCHAR(150),
		description VARCHAR(100),
		environment VARCHAR(100),
		isTranscribed VARCHAR(100),
		errorMessage VARCHAR(100),
		createdDate DATETIME,
		endDate DATETIME,
		campaign VARCHAR(50),
		dispositionCode VARCHAR(250),
		folder VARCHAR(50)
	)

	-- INSERTAMOS LOS REGISTROS CALL
	INSERT INTO #PROCESS_INTERACTIONS
		SELECT A.[VCC]						'vcc',
				'CALL'						'interactionType',
				A.[ID]						'id',
				A.[Section]					'section',
				A.[Part]					'part',
				PA.[ProcessId]				'processId',
				A.[Number]					'number',
				P.[Name]					'name',
				A.[SilenceTime]				'silenceTime',
				A.[DurationTime]			'durationTime',
				A.[DurationLinguisticTime]	'durationLinguisticTime',
				A.[Category1]				'category1',
				A.[Category2]				'category2',
				A.[Category3]				'category3',
				A.[Agent]					'agent',
				A.[AgentName]				'agentName',
				A.[Description]				'description',
				P.[Environment]				'environment',
				A.[IsTranscribed]			'isTranscribed',
				A.[ErrorMessage]			'errorMessage',
				A.[CreatedDate]				'createdDate',
				A.[EndDate]					'endDate',
				A.[Campaign]				'campaign',
				A.[DispositionCode]			'dispositionCode',
				NULL						'folder'
			FROM [dbo].[Audio] A (NOLOCK)
			INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
				ON A.ID = PA.AudioId 
					AND A.Section = PA.Section 
					AND A.Part = PA.Part
			INNER JOIN [dbo].[Process] P (NOLOCK) 
				ON PA.[ProcessId] = P.[Name]
			WHERE A.[VCC] = @VCC
				AND PA.[ProcessId] = @ProcessId
				AND P.[Type] = 'SPEECH'
				
	-- INSERTAMOS LOS REGISTROS DE INTERACCIONES DE OTROS CANALES
	INSERT INTO #PROCESS_INTERACTIONS
		SELECT AI.[VCC]																'vcc',
				AI.[Channel]														'interactionType',
				AI.[ID]																'id',
				NULL																'section',
				NULL																'part',
				PAI.[ProcessId]														'processId',
				AI.[ContactName]													'number',
				PAI.[ProcessId]														'name',
				NULL																'silenceTime',
				CASE WHEN TRY_CAST(AI.[DurationTime] AS INT) IS NULL THEN
					CAST(SUBSTRING(AI.[DurationTime], 1, CHARINDEX(':', AI.[DurationTime], 1) - 1) AS INT) * 3600
					+
					CAST(SUBSTRING(AI.[DurationTime], CHARINDEX(':', AI.[DurationTime], 1) + 1, 2) AS INT) * 60
					+
					CAST(SUBSTRING(AI.[DurationTime], CHARINDEX(':', AI.[DurationTime], CHARINDEX(':', AI.[DurationTime], 1) + 1) + 1, 2) AS INT)
				ELSE AI.[DurationTime]
				END																	'durationTime',
				NULL																'durationLinguisticTime',
				NULL																'category1',
				NULL																'category2',
				NULL																'category3',
				AI.[FirstTakedAgent]												'agent',
				ISNULL(AI.[LastTakedAgentName], AI.[LastTakedAgentName])			'agentName',
				AI.[DispositionCode]												'description',
				'I6'																'environment',
				AI.[IsTranscribed]													'isTranscribed',
				AI.[ErrorMessage]													'errorMessage',
				AI.[CreatedDate]													'createdDate',
				AI.[EndDate]														'endDate',
				AI.[Campaign]														'campaign',
				AI.[DispositionTreePath]											'dispositionCode',
				AI.[Folder]															'folder'
			FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
			INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON AI.[VCC] = PAI.[VCC]
					--AND AI.[Campaign] = PAI.[Campaign]
					AND AI.[Channel] = PAI.[InteractionType]
					AND AI.[ID] = PAI.[InteractionId]
					AND AI.[Folder] = PAI.[FormattedEndDate]
			INNER JOIN [dbo].[Process] P (NOLOCK) 
				ON P.[Name] = PAI.[ProcessId]
			WHERE PAI.[VCC] = @VCC
				AND PAI.[ProcessId] = @ProcessId
				AND P.[Type] = 'SPEECH'
		
	-- DECLARAMOS VARIABLE PARA LA CONSULTA ACUMULADA QUE LANZAREMOS
	DECLARE @SQL NVARCHAR(MAX) = ''
	DECLARE @SQL_WHERE_IDATHA NVARCHAR(MAX) = ''
    DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
	DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX )= ''	
	
	SET @SQL_WHERE_IDATHA = ''

	-- HACEMOS EL PRIMER QUERY PARA SACAR EL NUMERO DE REGISTROS DEL PROCESS
	SET @SQL = ' SET NOCOUNT ON
	DECLARE @rows INT
	DECLARE @SYNC_INTERACTIONS INT
	DECLARE @ASYNC_INTERACTIONS INT
	DECLARE @maxDurationTime Numeric(12,3)

	SELECT @SYNC_INTERACTIONS = COUNT(*) FROM #PROCESS_INTERACTIONS PI WHERE PI.[interactionType] = ''CALL''
	SELECT @ASYNC_INTERACTIONS = COUNT(*) FROM #PROCESS_INTERACTIONS PI WHERE PI.[interactionType] <> ''CALL''
	SELECT @maxDurationTime = MAX([durationTime]) FROM #PROCESS_INTERACTIONS 
	'

	SET @SQL += '
		SET @rows = (
			SELECT COUNT(PI.[id])
				FROM #PROCESS_INTERACTIONS PI (NOLOCK)
				WHERE PI.[vcc] = ''' + @VCC + ''' 
					'
	IF (@ProcessId IS NOT NULL) 
			SET @SQL += 'AND PI.[ProcessId]= ''' + @ProcessId + ''' 
						'

	IF(@Type = 'query')
	BEGIN
		SET @SQL_WHERE_IDATHA += 'AND ((CONCAT(PI.[id], ''_'', PI.[section], ''_'', PI.[part]) IN (''' + @IdathaResults + '''))
						OR (PI.[id] IN (''' + @IdathaResults + ''')))
					'
	
		SET @SQL += @SQL_WHERE_IDATHA

	END
	ELSE IF(@Type = 'allegro' OR @Type = 'ftp' OR @Type = 'sftp' OR @Type = 'fileSystem')
	BEGIN
		IF (@ID IS NOT NULL) 
			SET @FILTERS_OPTIONAL_PART += 'AND ((CONCAT(PI.[id], ''_'', PI.[section], ''_'', PI.[part]) LIKE ''%' + @ID + '%'')
						OR (PI.[id] = ''' + @ID + '''))
					'
		
		IF (@Campaign IS NOT NULL AND LEN(@Campaign) > 0) 
			SET @FILTERS_OPTIONAL_PART += 'AND PI.[campaign] IN (''' + @Campaign + ''')
						'
		
		IF (@Agent IS NOT NULL AND LEN(@Agent) > 0) 
			SET @FILTERS_OPTIONAL_PART += 'AND (
									(PI.[agent] IN (''' + @Agent + '''))
									OR 
									(PI.[agent] IS NULL)
								)
						'
		
		--CORREGIR
		-- (CONCAT(PI.campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), PI.[dispositionCode]), '''') IN (''' + @ResultCode + '''))
		IF (@ResultCode IS NOT NULL AND LEN(@ResultCode) > 0) 
			SET @FILTERS_OPTIONAL_PART += 'AND (
									(CONCAT(PI.campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), PI.[dispositionCode]), ''X'')) IN (''' + @ResultCode + '''))
									OR 
									--(CONCAT(PI.campaign, ''_'', ISNULL(PI.[dispositionCode], ''X'')) IN (''' + @ResultCode + '''))
									(CONCAT(PI.campaign, ISNULL(REPLACE(PI.[dispositionCode], ''/'', ''_''), ''_'')) IN (''' + @ResultCode + '''))
									) '
		
		IF (@InteractionType IS NOT NULL AND LEN(@InteractionType) > 0) 
			SET @FILTERS_OPTIONAL_PART += 'AND PI.[interactionType] = ''' + @InteractionType + ''' 
						'

		IF (@Folder IS NOT NULL AND LEN(@Folder) > 0) 
			SET @FILTERS_OPTIONAL_PART += 'AND PI.[folder] = ''' + @Folder + ''' 
						'

		IF (@Folder IS NOT NULL AND LEN(@Folder) > 0) 

		IF (@StartDate IS NOT NULL AND @EndDate IS NOT NULL) 
			SET @FILTERS_OPTIONAL_PART += 'AND PI.[endDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' 
						AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
						'
		
		IF (@StartHour IS NOT NULL AND @EndHour IS NOT NULL) 
			SET @FILTERS_OPTIONAL_PART += 'AND DATEPART(HOUR, PI.[endDate]) >= ' + CONVERT(VARCHAR, @StartHour) + ' 
						AND DATEPART(HOUR, PI.[endDate]) <= ' + CONVERT(VARCHAR, @EndHour) + '
						'
		
		IF (@StartMinute IS NOT NULL AND @EndMinute IS NOT NULL) 
			SET @FILTERS_OPTIONAL_PART += 'AND DATEPART(MINUTE, PI.[endDate]) >= ' + CONVERT(VARCHAR, @StartMinute) + ' 
						AND DATEPART(MINUTE, PI.[endDate]) <= ' + CONVERT(VARCHAR, @EndMinute) + '
						'

		IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
        BEGIN
			SET @FILTERS_OPTIONAL_PART = ''
			SET @FILTERS_EXCLUDING_PART = ' AND PI.[id] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) 
						'
	    END
		
	END

	SET @SQL += @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART
	SET @SQL += ') '
	SET @SQL += 'SELECT @rows AS total, 
						@maxDurationTime AS maxDurationTime,
						@ASYNC_INTERACTIONS AS asyncDetails, 
						@SYNC_INTERACTIONS AS audios '

	-- SECCION DE QUERY PARA RESUMEN DE CANALES
	SET @SQL += '
		SELECT PI.[interactionType]			''interactionType'',
				COUNT(*)					''interactions'' 
			FROM #PROCESS_INTERACTIONS PI 
			WHERE PI.[vcc] = ''' + @VCC + ''' 
	'

	IF(@ProcessId IS NOT NULL) 
		SET @SQL += '
				AND PI.[processId] = ''' + @ProcessId + ''' '
		
	SET @SQL += '
		GROUP BY  PI.[interactionType] '

	-- SECCION DE QUERY PARA RESUMEN DE CAMPANAS
	SET @SQL += '
		SELECT PI.[campaign]			''campaign''
			FROM #PROCESS_INTERACTIONS PI 
			WHERE PI.[vcc] = ''' + @VCC + ''' 
	'

	IF(@ProcessId IS NOT NULL) 
		SET @SQL += '
				AND PI.[processId] = ''' + @ProcessId + ''' '
		
	SET @SQL += '
		GROUP BY  PI.[campaign] '

	-- SECCION DE QUERY PARA LISTADO DE DETALLES(AUDIOS/TEXTOS)
	SET @SQL += '
		SELECT PI.[interactionType],
				PI.[id],
				PI.[section],
				PI.[part],
				PI.[processId],
				PI.[folder],
				PI.[campaign],
				PI.[number],
				PI.[name],
				PI.[silenceTime],
				PI.[durationTime],
				PI.[durationLinguisticTime],
				PI.[category1],
				PI.[category2],
				PI.[category3],
				PI.[agent],
				PI.[agentName],
				PI.[description],
				PI.[environment],
				PI.[isTranscribed],
				PI.[errorMessage],
				PI.[createdDate],
				PI.[endDate]
			FROM #PROCESS_INTERACTIONS PI
			WHERE PI.[vcc] = ''' + @VCC + ''' 
				'

	IF(@ProcessId IS NOT NULL) SET @SQL += 'AND PI.[processId] = ''' + @ProcessId + ''' '
			
	SET @SQL += ' '

	SET @SQL += @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART
	SET @SQL += @SQL_WHERE_IDATHA
	SET @SQL += 'ORDER BY PI.[ID], 
						PI.[ProcessId], 
						PI.[Agent], 
						PI.[AgentName], 
						PI.[Description], 
						PI.[Environment], 
						PI.[DurationTime], 
						PI.[CreatedDate]
			OFFSET ' + CONVERT(VARCHAR(50), @PageSize) + ' * (' + CONVERT(VARCHAR(50), @PageNumber) + ' - 1) ROWS
			FETCH NEXT ' + CONVERT(VARCHAR(50), @PageSize) + ' ROWS ONLY
			'

	SET @SQL += ' SET NOCOUNT OFF'
	--select @SQL
	EXEC(@SQL)
	
	DROP TABLE #PROCESS_INTERACTIONS
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
